        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>23</strong> miembros: 15 <br>2,3,7,9,11,18,20,22,23,31,33,38,39,40,48';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 13 <br>6,8,14,15,26,28,30,32,34,36,37,44,45';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>4,10,12,13,17,25,27,41,43,50';}
       if(rr==4 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 9 <strong>control</strong><br>0,5,19,21,24,29,42,46,47';}
       if(rr==4 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>16</strong> miembros: 4 <br>1,16,35,49';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>23</strong> miembros: 15 <br>2,3,7,9,11,18,20,22,23,31,33,38,39,40,48';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 13 <br>6,8,14,15,26,28,30,32,34,36,37,44,45';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>4,10,12,13,17,25,27,41,43,50';}
       if(rr==23 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 9 <strong>control</strong><br>0,5,19,21,24,29,42,46,47';}
       if(rr==23 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>16</strong> miembros: 4 <br>1,16,35,49';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>23</strong> miembros: 15 <br>2,3,7,9,11,18,20,22,23,31,33,38,39,40,48';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 13 <br>6,8,14,15,26,28,30,32,34,36,37,44,45';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>4,10,12,13,17,25,27,41,43,50';}
       if(rr==25 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 9 <strong>control</strong><br>0,5,19,21,24,29,42,46,47';}
       if(rr==25 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>16</strong> miembros: 4 <br>1,16,35,49';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>23</strong> miembros: 15 <br>2,3,7,9,11,18,20,22,23,31,33,38,39,40,48';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 13 <br>6,8,14,15,26,28,30,32,34,36,37,44,45';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>4,10,12,13,17,25,27,41,43,50';}
       if(rr==26 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 9 <strong>control</strong><br>0,5,19,21,24,29,42,46,47';}
       if(rr==26 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>16</strong> miembros: 4 <br>1,16,35,49';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>23</strong> miembros: 15 <br>2,3,7,9,11,18,20,22,23,31,33,38,39,40,48';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 13 <br>6,8,14,15,26,28,30,32,34,36,37,44,45';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>4,10,12,13,17,25,27,41,43,50';}
       if(rr==27 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 9 <strong>control</strong><br>0,5,19,21,24,29,42,46,47';}
       if(rr==27 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>16</strong> miembros: 4 <br>1,16,35,49';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>23</strong> miembros: 15 <br>2,3,7,9,11,18,20,22,23,31,33,38,39,40,48';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 13 <br>6,8,14,15,26,28,30,32,34,36,37,44,45';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>4</strong> miembros: 10 <br>4,10,12,13,17,25,27,41,43,50';}
       if(rr==28 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 9 <strong>control</strong><br>0,5,19,21,24,29,42,46,47';}
       if(rr==28 && cc==5){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260810 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>16</strong> miembros: 4 <br>1,16,35,49';}
}
